@@ -103,7 +103,7 @@ class TestSubprocesses(unittest.TestCase):
 
 
     def tearDown(self):
-        os.chdir(self.container_dir)
+        os.chdir(self.startdir)
         # On windows, the subprocesses block access to the files while
         # they take a bit to clean themselves up.
         for i in range(20):
@@ -205,3 +205,10 @@ class A(unittest.TestCase):
         os.chdir(TestSubprocesses.startdir)
         gtr = GreenTestRunner(self.stream, subprocesses=2, termcolor=False)
         self.assertRaises(ImportError, gtr.run, (tests,))
+
+
+    def test_empty(self):
+        "GreenTestRunner.run() does not crash with empty suite and subprocesses"
+        suite = unittest.TestSuite()
+        gtr = GreenTestRunner(self.stream, subprocesses=2, termcolor=False)
+        gtr.run(suite)
